==> flyyfluttersdk-1.0.0%2B1.tar.gz: lib/Flyy.dart <==
import 'dart:convert';

import 'package:android_play_install_referrer/android_play_install_referrer.dart';
import 'package:flutter/material.dart';
import 'package:flyyfluttersdk/helpers/APIClient.dart';
import 'package:flyyfluttersdk/helpers/FlyyUtility.dart';
import 'package:flyyfluttersdk/helpers/SharedPrefTags.dart';
import 'package:flyyfluttersdk/model/FlyyEventResponse.dart';
import 'package:flyyfluttersdk/model/FlyyUserData.dart';
import 'package:shared_preferences/shared_preferences.dart';

import 'model/FlyyAppInfo.dart';

class Flyy {
  static String APP_PACKAGE, PARTNER_TOKEN, EXT_USER_ID, USER_NAME;
  static Color STATUSBAR_COLOR, TOOLBAR_COLOR;
  static SharedPreferences sharedPreferences;

  static void init(String partnerKey) async {
    if (partnerKey == null || partnerKey.length == 0) {
      print('Flyy Init", "init failed, please provide all the data.');
      return;
    }

    Flyy.STATUSBAR_COLOR = Colors.black;
    Flyy.TOOLBAR_COLOR = Colors.black;
    Flyy.PARTNER_TOKEN = partnerKey;

    fetchAppInfo();

    sharedPreferences = await SharedPreferences.getInstance();
    if (sharedPreferences.getBool(SharedPrefTags.IS_FIRST_OPENED) == null ||
        !sharedPreferences.getBool(SharedPrefTags.IS_FIRST_OPENED)) {
      initReferrerDetails();
//      sendEvent("Registration", "Done");
//      sendEvent("Registration", "Done");
      sharedPreferences.setBool(SharedPrefTags.IS_FIRST_OPENED, true);
    }

    sharedPreferences.setString(SharedPrefTags.FLYY_PARTNER_KEY, partnerKey);
    sharedPreferences.setString(SharedPrefTags.FLYY_APP_PACKAGE,
        FlyyUtility.getPackageInfo().packageName);
    sharedPreferences.setString(
        SharedPrefTags.FLYY_VERSION, FlyyUtility.getPackageInfo().version);
    sharedPreferences.setString(SharedPrefTags.FLYY_BUILD_NUMBER,
        FlyyUtility.getPackageInfo().buildNumber);
  }

  ///To catch installation from playstore
  // Platform messages are asynchronous, so we initialize in an async method.
  static Future<void> initReferrerDetails() async {
    String referrerDetailsString;
    // Platform messages may fail, so we use a try/catch PlatformException.
    try {
      ReferrerDetails referrerDetails =
          await AndroidPlayInstallReferrer.installReferrer;

      referrerDetailsString = referrerDetails.installReferrer;
      if (referrerDetailsString != null && referrerDetailsString.isNotEmpty) {
        sendEvent("install", referrerDetailsString);
//        sendAppInstalledEvent(referrerDetailsString);
      }
    } catch (e) {
      referrerDetailsString = 'Failed to get referrer details: $e';
    }
  }

  ///fetch app information
  static Future<FlyyAppInfo> fetchAppInfo() async {
    final response = await APIClient.getClient("v1/flyy_app_info");
    if (response.statusCode == 200 && response.body != null) {
      final responseJson = json.decode(response.body);

      FlyyUtility.fetchWalletData();

      sharedPreferences = await SharedPreferences.getInstance();

      sharedPreferences.setString(SharedPrefTags.FLYY_APP_INFO, response.body);

      return FlyyAppInfo.fromJson(responseJson);
    } else {
      throw Exception('Failed to load data ' + response.toString());
    }
  }

  ///send event method
  static Future<FlyyEventResponse> sendEvent(String key, String value) async {
    Map<String, String> bodyParams = new Map();
    bodyParams['key'] = key.toLowerCase();
    bodyParams['value'] = value.toLowerCase();

    final response =
        await APIClient.postClient("track_flyy_event", bodyParams, key, value);
    if (response.statusCode == 200) {
      final responseJson = json.decode(response.body);
      FlyyEventResponse flyyEventResponse =
          FlyyEventResponse.fromJson(responseJson);

      if (key != null && (key == "registration" || key == "install")) {
        fetchAppInfo();
      }

      if (!flyyEventResponse.success) sendEvent(key, value);

      return flyyEventResponse;
    } else {
      sendEvent(key, value);
    }
    return null;
  }

  ///send installed event
//  static Future<FlyyEventResponse> sendAppInstalledEvent(
//      String referrerUrl) async {
//    Map<String, String> bodyParams = new Map();
//    bodyParams['referrer'] = referrerUrl;
//
//    final response =
//        await APIClient.postClient("app_installed", bodyParams, null, null);
//    if (response.statusCode == 200) {
//      final responseJson = json.decode(response.body);
//      FlyyEventResponse flyyEventResponse =
//          FlyyEventResponse.fromJson(responseJson);
//
//      return flyyEventResponse;
//    } else {
//      sendAppInstalledEvent(referrerUrl);
//    }
//    return null;
//  }

  static void setUsername(String userName) {
    Flyy.USER_NAME = userName;
    setUserData("user_name", userName);
  }

//    public static void setContactNumber(String contact_number){
//        setUserData("contact_number", contact_number);
//    }

  static void setExtUid(String exUid) {
    Flyy.EXT_USER_ID = exUid;
    setUserData("ext_uid", exUid);
  }

  static Future<FlyyUserData> setUserData(String key, String value) async {
    Map<String, String> bodyParams = new Map();
    bodyParams[key] = value.toLowerCase();

    var response;

    switch (key) {
      case "user_name":
        response = await APIClient.putClient("v1/set_user_name", bodyParams);
        break;
      case "contact_number":
        response =
            await APIClient.putClient("v1/set_contact_number", bodyParams);
        break;
      case "ext_uid":
        response = await APIClient.putClient("v1/set_ext_uid", bodyParams);
        break;
    }

    if (response.statusCode == 200) {
      final responseJson = json.decode(response.body);
      FlyyUserData flyyUserData = FlyyUserData.fromJson(responseJson);

      if (!flyyUserData.success) setUserData(key, value);

      return flyyUserData;
    } else {
      setUserData(key, value);
    }
    return null;
  }
}

==> flyyfluttersdk-1.0.1%2B1.tar.gz: lib/Flyy.dart <==
import 'dart:convert';

import 'package:android_play_install_referrer/android_play_install_referrer.dart';
import 'package:flutter/material.dart';
import 'package:flyyfluttersdk/helpers/APIClient.dart';
import 'package:flyyfluttersdk/helpers/FlyyUtility.dart';
import 'package:flyyfluttersdk/helpers/SharedPrefTags.dart';
import 'package:flyyfluttersdk/model/FlyyEventResponse.dart';
import 'package:flyyfluttersdk/model/FlyyUserData.dart';
import 'package:shared_preferences/shared_preferences.dart';

import 'model/FlyyAppInfo.dart';

class Flyy {
  static String APP_PACKAGE, PARTNER_TOKEN, EXT_USER_ID, USER_NAME;
  static Color STATUSBAR_COLOR, TOOLBAR_COLOR;
  SharedPreferences sharedPreferences;
  FlyyUtility flyyUtility;
  APIClient apiClient;

  void init(String partnerKey) async {
    if (partnerKey == null || partnerKey.length == 0) {
      print('Flyy Init", "init failed, please provide all the data.');
      return;
    }

    flyyUtility = new FlyyUtility();

    Flyy.STATUSBAR_COLOR = Colors.black;
    Flyy.TOOLBAR_COLOR = Colors.black;
    Flyy.PARTNER_TOKEN = partnerKey;

    fetchAppInfo();

    sharedPreferences = await SharedPreferences.getInstance();
    if (sharedPreferences.getBool(SharedPrefTags.IS_FIRST_OPENED) == null ||
        !sharedPreferences.getBool(SharedPrefTags.IS_FIRST_OPENED)) {
      initReferrerDetails();
//      sendEvent("Registration", "Done");
//      sendEvent("Registration", "Done");
      sharedPreferences.setBool(SharedPrefTags.IS_FIRST_OPENED, true);
    }

    sharedPreferences.setString(SharedPrefTags.FLYY_PARTNER_KEY, partnerKey);
    sharedPreferences.setString(SharedPrefTags.FLYY_APP_PACKAGE,
        flyyUtility.getPackageInfo().packageName);
    sharedPreferences.setString(
        SharedPrefTags.FLYY_VERSION, flyyUtility.getPackageInfo().version);
    sharedPreferences.setString(SharedPrefTags.FLYY_BUILD_NUMBER,
        flyyUtility.getPackageInfo().buildNumber);
  }

  ///To catch installation from playstore
  // Platform messages are asynchronous, so we initialize in an async method.
  Future<void> initReferrerDetails() async {
    String referrerDetailsString;
    // Platform messages may fail, so we use a try/catch PlatformException.
    try {
      ReferrerDetails referrerDetails =
          await AndroidPlayInstallReferrer.installReferrer;

      referrerDetailsString = referrerDetails.installReferrer;
      if (referrerDetailsString != null && referrerDetailsString.isNotEmpty) {
        sendEvent("install", referrerDetailsString);
//        sendAppInstalledEvent(referrerDetailsString);
      }
    } catch (e) {
      referrerDetailsString = 'Failed to get referrer details: $e';
    }
  }

  ///fetch app information
  Future<FlyyAppInfo> fetchAppInfo() async {
    apiClient = new APIClient();
    final response = await apiClient.getClient("v1/flyy_app_info");
    if (response.statusCode == 200 && response.body != null) {
      final responseJson = json.decode(response.body);

      flyyUtility.fetchWalletData();

      sharedPreferences = await SharedPreferences.getInstance();

      sharedPreferences.setString(SharedPrefTags.FLYY_APP_INFO, response.body);

      return FlyyAppInfo.fromJson(responseJson);
    } else {
      throw Exception('Failed to load data ' + response.toString());
    }
  }

  ///send event method
  Future<FlyyEventResponse> sendEvent(String key, String value) async {
    Map<String, String> bodyParams = new Map();
    bodyParams['key'] = key.toLowerCase();
    bodyParams['value'] = value.toLowerCase();

    apiClient = new APIClient();
    final response =
        await apiClient.postClient("track_flyy_event", bodyParams, key, value);
    if (response.statusCode == 200) {
      final responseJson = json.decode(response.body);
      FlyyEventResponse flyyEventResponse =
          FlyyEventResponse.fromJson(responseJson);

      if (key != null && (key == "registration" || key == "install")) {
        fetchAppInfo();
      }

      if (!flyyEventResponse.success) sendEvent(key, value);

      return flyyEventResponse;
    } else {
      sendEvent(key, value);
    }
    return null;
  }

  ///send installed event
//  static Future<FlyyEventResponse> sendAppInstalledEvent(
//      String referrerUrl) async {
//    Map<String, String> bodyParams = new Map();
//    bodyParams['referrer'] = referrerUrl;
//
//    final response =
//        await APIClient.postClient("app_installed", bodyParams, null, null);
//    if (response.statusCode == 200) {
//      final responseJson = json.decode(response.body);
//      FlyyEventResponse flyyEventResponse =
//          FlyyEventResponse.fromJson(responseJson);
//
//      return flyyEventResponse;
//    } else {
//      sendAppInstalledEvent(referrerUrl);
//    }
//    return null;
//  }

  void setUsername(String userName) {
    Flyy.USER_NAME = userName;
    setUserData("user_name", userName);
  }

//    public static void setContactNumber(String contact_number){
//        setUserData("contact_number", contact_number);
//    }

  void setExtUid(String exUid) {
    Flyy.EXT_USER_ID = exUid;
    setUserData("ext_uid", exUid);
  }

  Future<FlyyUserData> setUserData(String key, String value) async {
    Map<String, String> bodyParams = new Map();
    bodyParams[key] = value.toLowerCase();

    var response;
    apiClient = new APIClient();

    switch (key) {
      case "user_name":
        response = await apiClient.putClient("v1/set_user_name", bodyParams);
        break;
      case "contact_number":
        response =
            await apiClient.putClient("v1/set_contact_number", bodyParams);
        break;
      case "ext_uid":
        response = await apiClient.putClient("v1/set_ext_uid", bodyParams);
        break;
    }

    if (response.statusCode == 200) {
      final responseJson = json.decode(response.body);
      FlyyUserData flyyUserData = FlyyUserData.fromJson(responseJson);

      if (!flyyUserData.success) setUserData(key, value);

      return flyyUserData;
    } else {
      setUserData(key, value);
    }
    return null;
  }
}
